package jp.oarts.pirka.core.ctrl.proc.def;

import java.util.List;
import java.util.Map;

import jp.oarts.pirka.core.analyzer.html.HtmlTools;
import jp.oarts.pirka.core.ctrl.proc.CtrlProcesser;
import jp.oarts.pirka.core.err.ErrorMessageManagerIF;
import jp.oarts.pirka.core.err.ErrorMessageStocker;
import jp.oarts.pirka.core.general.HtmlCtrlParts;
import jp.oarts.pirka.core.general.HtmlParts;
import jp.oarts.pirka.core.general.WindowBaseData;
import jp.oarts.pirka.core.util.field.FieldItem;

/**
 * TEXTAREA^OvZbT[
 * 
 * @author ito
 * 
 */
public class TextareaProcesser extends CtrlProcesser {

	/**
	 * HTMLp[cXg̎^O̎qp[c̃^O鎞trueԂ
	 * 
	 * @return true=qp[c̃^O
	 */
	@Override
	public boolean isUseChild() {
		return true;
	}

	/**
	 * [v^O̎tureԂ
	 * 
	 * @return true=[v^O
	 */
	@Override
	public boolean isLoop() {
		return false;
	}

	/**
	 * XCb`^O̎tureԂ
	 * 
	 * @return true=XCb`^O
	 */
	public boolean isSwitch() {
		return false;
	}

	/**
	 * uEUœ͂sȂ^ÔƂrtueԂ
	 * 
	 * @return true=uEUœ
	 */
	@Override
	public boolean isInputCtrl() {
		return true;
	}

	/**
	 * uEU[̃ANVƂtureԂ
	 * 
	 * @return true=ANV
	 */
	@Override
	public boolean isActionCtrl() {
		return false;
	}

	/**
	 * O[sOsȂ^OiWI{^Ȃǁj̊evf̎tureԂ
	 * 
	 * @return true=O[sOvf
	 */
	public boolean isGroupItem() {
		return false;
	}

	/**
	 * `FbNsȂRg[̎tureԂ
	 * 
	 * @return true=`FbNsȂRg[
	 */
	public boolean isCheckCtrl() {
		return false;
	}

	/**
	 * tH[}bg\ȃRg[̎tureԂ
	 * 
	 * @return true=tH[}bg\ȃRg[
	 */
	public boolean isFormatCtrl() {
		return true;
	}

	/**
	 * f[^̃ZbgsȂ
	 * 
	 * @param data
	 */
	public void setValue(Object data, FieldItem fieldItem) {
		if (data == null || !(data instanceof String)) {
			throw new RuntimeException("w肳ꂽl̓Zbgł܂ StringIuWFNgZbgĂ");
		}

		fieldItem.setValue((String) data);
	}

	/**
	 * l͂
	 * 
	 * @param ctrl
	 *            Rg[
	 * @param list
	 *            ̃^OHTMLp[c̃Xg
	 */
	@Override
	public void analyzeInitValue(HtmlCtrlParts ctrl, List<HtmlParts> list) {
		// l͋Ƃ
		// ctrl.setDefaultValue(HtmlTools.toSimpleString(list)); // ꕶΉ

	}

	/**
	 * ^O쐬
	 * 
	 * @param ctrl
	 *            Rg[p[c
	 * @param loopSuffix
	 *            [vTtBbNX
	 * @param value
	 *            l
	 * @param checked
	 *            `FbNl
	 * @param windowBaseData
	 *            ʃf[^
	 * @param errorMessageManager
	 *            G[bZ[W}l[W[
	 * @param errorMessageStocker
	 *            G[bZ[WXgbJ[
	 * @param errorFlag
	 *            G[tO true=G[
	 * @param workMap
	 *            Ɨp}bv
	 * 
	 * @return 쐬ꂽ^O
	 */
	public String makeStartTag(HtmlCtrlParts ctrl, String loopSuffix, String value, boolean checked, WindowBaseData windowBaseData, //
			ErrorMessageManagerIF errorMessageManager, ErrorMessageStocker errorMessageStocker, boolean errorFlag, Map<String, Object> workMap) {

		Map<String, String> optionMap = ctrl.getOptionMap();
		if (errorFlag) {
			optionMap = changeStyle(errorMessageManager.getNgStyle(), optionMap);
		}
		StringBuilder sb = new StringBuilder();

		sb.append('<');
		sb.append(ctrl.getTagName());
		sb.append(createOptionString(ctrl.getTypeOption(), ctrl.getName() + loopSuffix, loopSuffix, value, ctrl.isSuffix(), optionMap));
		sb.append(">");
		sb.append(HtmlTools.webString(value));
		return sb.toString();
	}

	/**
	 * }bv𕶎ɕϊ
	 * 
	 * @param type
	 *            ^Cv
	 * @param name
	 *            ^O
	 * @param loopSuffix
	 *            [vTtBbNX
	 * @param value
	 *            livaluej
	 * @param isSuffix
	 *            TbtBbNXtO
	 * @param optionMap
	 *            }bv
	 * @return ϊꂽ
	 */
	protected String createOptionString(String type, String name, String loopSuffix, String value, boolean isSuffix, Map<String, String> optionMap) {
		StringBuilder sb = new StringBuilder();

		if (type != null && type.length() > 0) {
			sb.append(" type=\"");
			sb.append(type);
			sb.append("\"");
		}

		if (name != null && name.length() > 0) {
			sb.append(" name=\"");
			sb.append(name);
			sb.append("\"");
		}

		for (String key : optionMap.keySet()) {
			if (!key.equalsIgnoreCase("type") && !key.equalsIgnoreCase("name") && !key.equalsIgnoreCase("value")) {
				addOption(sb, optionMap, key, isSuffix, loopSuffix);
			}
		}

		return sb.toString();
	}

}
